<?php

namespace Drupal\speakeasy\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Controller for voice autocomplete functionality.
 */
class VoiceAutocompleteController extends ControllerBase {

  /**
   * Detect the current browser based on the User-Agent header.
   */
  private function getCurrentBrowser() {
    $ua = strtolower($_SERVER['HTTP_USER_AGENT'] ?? '');
    \Drupal::logger('speakeasy')->debug('User-Agent: @ua', ['@ua' => $ua]);
    if (strpos($ua, 'chrome') !== FALSE && strpos($ua, 'edg') === FALSE) {
      return 'chrome';
    }
    elseif (strpos($ua, 'edg') !== FALSE) {
      return 'edge';
    }
    elseif (strpos($ua, 'firefox') !== FALSE) {
      return 'firefox';
    }
    elseif (strpos($ua, 'safari') !== FALSE && strpos($ua, 'chrome') === FALSE) {
      return 'safari';
    }
    return 'other';
  }

  /**
   * Autocomplete handler for voice names.
   */
  public function autocomplete(Request $request, $browser) {
    $q = $request->query->get('q', '');
    $matches = [];
    $current_browser = $this->getCurrentBrowser();

    \Drupal::logger('speakeasy')->debug('Autocomplete called - Browser: @browser, Current Browser: @current, Query: @q', [
      '@browser' => $browser,
      '@current' => $current_browser,
      '@q' => $q,
    ]);

    // Get voices from state for the current browser.
    $available_voices = [];
    if ($browser === $current_browser) {
      $stored_voices = \Drupal::state()->get('speakeasy_available_voices', []);
      \Drupal::logger('speakeasy')->debug('Stored voices from state: @voices', [
        '@voices' => print_r($stored_voices, TRUE),
      ]);
      if (!empty($stored_voices) && is_array($stored_voices)) {
        $available_voices = $stored_voices;
      }
    }

    // Fallback lists for non-active browsers or if no voices are stored.
    if (empty($available_voices)) {
      \Drupal::logger('speakeasy')->debug('Using fallback voices for @browser', ['@browser' => $browser]);
      switch ($browser) {
        case 'chrome':
          $available_voices = [
            ['name' => 'Google US English', 'lang' => 'en-US'],
            ['name' => 'Google UK English Female', 'lang' => 'en-GB'],
            ['name' => 'Google español', 'lang' => 'es-ES'],
          ];
          break;

        case 'edge':
          $available_voices = [
            ['name' => 'Microsoft David Desktop', 'lang' => 'en-US'],
            ['name' => 'Microsoft Zira Desktop', 'lang' => 'en-US'],
            ['name' => 'Microsoft Mark Mobile', 'lang' => 'en-US'],
          ];
          break;

        case 'firefox':
          $available_voices = [
            ['name' => 'Mozilla TTS Voice', 'lang' => 'en-US'],
            ['name' => 'Mozilla TTS UK', 'lang' => 'en-GB'],
          ];
          break;

        case 'safari':
          $available_voices = [
            ['name' => 'Samantha', 'lang' => 'en-US'],
            ['name' => 'Alex', 'lang' => 'en-US'],
            ['name' => 'Victoria', 'lang' => 'en-GB'],
          ];
          break;

        case 'other':
        default:
          $available_voices = [
            ['name' => 'Google US English', 'lang' => 'en-US'],
            ['name' => 'Microsoft David Desktop', 'lang' => 'en-US'],
            ['name' => 'Mozilla TTS Voice', 'lang' => 'en-US'],
          ];
          break;
      }
    }

    if ($q) {
      foreach ($available_voices as $voice) {
        if (stripos($voice['name'], $q) !== FALSE) {
          $matches[] = [
            'value' => $voice['name'],
            'label' => $voice['name'] . ' (' . $voice['lang'] . ')',
          ];
        }
      }
    }

    \Drupal::logger('speakeasy')->debug('Autocomplete matches: @matches', [
      '@matches' => print_r($matches, TRUE),
    ]);

    return new JsonResponse($matches);
  }
}