<?php

namespace Drupal\speakeasy\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\JsonResponse;

class VoiceStorageController extends ControllerBase {

  /**
   * Stores voices sent via AJAX request.
   */
  public function storeVoices(Request $request) {
    // Handle JSON payload if Content-Type is application/json.
    if ($request->headers->get('Content-Type') === 'application/json') {
      $data = json_decode($request->getContent(), TRUE);
      $voices = $data['voices'] ?? null;
    }
    else {
      // Fallback to form-encoded data (e.g., from Drupal.ajax).
      $voices = $request->request->get('voices', null);
    }

    // Validate that voices is an array and not empty.
    if (is_array($voices) && !empty($voices)) {
      \Drupal::state()->set('speakeasy_available_voices', $voices);
      return new JsonResponse(['status' => 'success']);
    }

    // Return an error response if the data is invalid.
    return new JsonResponse(['status' => 'error', 'message' => 'Invalid or empty voices data'], 400);
  }
}